clear all
close all
clc
data ={'ERA5','CLIM30','CLIM30ML'};
plot_color = {'-k','--k','-b'};
region = {'Global','Tropics','MidLat','CONUS','NEUS','NEURO','NWP'};
var = {'U','V','T','Q'};
units ={'$m/s$','$m/s$','$K$','$g/kg$'};
level =  '58';


% Plots global and regional probability density functions
%% Plots
nIDs = 26;
alphabet = ('a':'z').';
chars = num2cell(alphabet(1:nIDs));
chars = chars.';
charlbl = strcat('(',chars,')'); % {'(a)','(b)','(c)','(d)'}
text(0.025,0.95,charlbl{1},'Units','normalized','FontSize',12)


for jr = 1:length(region)
    figure(jr)
    tcl = tiledlayout(2,2);
    for jv = 1:4
        nexttile(tcl)
        for jd =1:3
            source = ['pdf/',data{jd},'_',region{jr},'_',var{jv},'_lev',level,'_pdf_monthly_1979-2014.nc'];
            % ncdisp(source)
            x = ncread(source,'x');
            name = [var{jv},'_',region{jr}];
            p = ncread(source,name);
            plot(x,p,plot_color{jd},'linewidth',3);hold on
            set(gca,'FontSize',25,'fontname','times','yscale','log')
            xlabel([units{jv}],'Interpreter','latex')
            ylabel('$p$','Interpreter','latex')
            if jd ==1
                ylim([min(p),max(p)*2])
            end
            text(0.025,0.95,charlbl{jv},'Units','normalized','FontSize',30,'FontName','times')

            grid on
        end
    end
    hL = legend('$RD$','$CR$','$ML(CR)$','Location','northoutside','Interpreter','latex','Orientation','horizontal');
    hL.Layout.Tile = 'North';legend boxoff
end



%% Appendix Plots
xlimv= {[-10,10],[-10,10],[260,320],[0,20]};
region = {'CONUS','NEUS','NEURO'};
region_title = {'Cont. US','N.E. US','N. Europe'};
figure(10);close;figure(10)
tcl = tiledlayout(4,length(region));
jp =1;

for jv = 1:4
    for jr = 1:length(region)

        figure(10);
        nexttile(tcl)
        for jd = 1:3
            source = ['pdf/',data{jd},'_',region{jr},'_',var{jv},'_lev',level,'_pdf_monthly_1979-2014.nc'];
            % ncdisp(source)
            x = ncread(source,'x');
            name = [var{jv},'_',region{jr}];
            p = ncread(source,name);

            % Plot
            plot(x,p,plot_color{jd},'linewidth',1);hold on
            set(gca,'FontSize',20,'fontname','times','yscale','log')
            xlabel([units{jv}],'Interpreter','latex')
            ylabel('$p$','Interpreter','latex')
            if jd ==1
                ylim([min(p),max(p)*2])
            end
            xlim(xlimv{jv})
            grid on
            % if jr ~= 7
            %     xmarkers([]);
            % end)
        end
        text(0.025,0.95,charlbl{jp},'Units','normalized','FontSize',20,'FontName','times')
        jp =jp+1;
        if jv ==1
            title(region_title{jr})
        end

    end
end
figure(10)
hL = legend('$RD$','$CR$','$ML(CR)$','Location','northoutside','Interpreter','latex','Orientation','horizontal','fontsize',35);
hL.Layout.Tile = 'North';legend boxoff
